@@ -161,12 +161,12 @@ module uspack
 
     end subroutine
 !----------------------------------
-!   UXYZPACK W
-!---------------------------------- ڐƃx̊Ԋuw肵čW`
+!   UXYZPACK 座標軸
+!---------------------------------- 目盛とラベルの間隔を指定して座標軸を描く
     subroutine DclDrawAxis(side,dlabel,dtick, &
                          & title,unit,factor,offset,section) 
-      character(len=*), intent(in) :: side !W`ꏊ
-      real, intent(in) :: dlabel, dtick    !ڐуx̊Ԋu
+      character(len=*), intent(in) :: side !座標軸を描く場所
+      real, intent(in) :: dlabel, dtick    !目盛およびラベルの間隔
       character(len=*), intent(in), optional :: title, unit
       real, intent(in), optional :: factor,offset,section
 
@@ -191,13 +191,13 @@ module uspack
       call sgocls('DclDrawAxis')
 
     end subroutine
-!---------------------------------- ڐƃx̏ꏊw肵čW`D
+!---------------------------------- 目盛とラベルの場所を指定して座標軸を描く．
     subroutine DclDrawAxisSpecify(side,label_pos,tick_pos,label, &
                                 & title, unit, factor, offset, section)
-      character(len=*), intent(in) :: side       !W`ꏊ
-      real, intent(in), dimension(:) :: label_pos       !傫߂̖ڐуx̏ꏊ
-      real, intent(in), dimension(:), optional :: tick_pos      !߂̖ڐ̏ꏊ
-      character(len=*), intent(in), dimension(:), optional :: label !x
+      character(len=*), intent(in) :: side       !座標軸を描く場所
+      real, intent(in), dimension(:) :: label_pos       !大きめの目盛およびラベルの場所
+      real, intent(in), dimension(:), optional :: tick_pos      !小さめの目盛の場所
+      character(len=*), intent(in), dimension(:), optional :: label !ラベル
       character(len=*), intent(in), optional :: title, unit
       real, intent(in), optional :: factor, offset, section
       real,dimension(1) :: dummy
@@ -233,10 +233,10 @@ module uspack
       call sgocls('DclDrawAxisSpecify')
 
     end subroutine
-!---------------------------------- LOG W`D
+!---------------------------------- LOG 座標軸を描く．
     subroutine DclDrawAxisLog(side, nlabel, nticks, &
                             & title, unit, format, factor, section, label_pos)
-      character(len=*), intent(in)  :: side       !W`ꏊ
+      character(len=*), intent(in)  :: side       !座標軸を描く場所
       integer, intent(in)           :: nlabel, nticks
       integer, intent(in), optional :: format
       character(len=*), intent(in), optional :: title, unit
@@ -286,14 +286,14 @@ module uspack
 
     end subroutine
 !----------------------------------------
-!   tW
+!   日付座標軸
 !----------------------------------------
-    subroutine DclDrawAxisCalendar (side,first_day, title, unit, type,nd) !EENɊւW`D
-      character(len=*),  intent(in) :: side       !Wꏊw肷
-      type(dcl_date),    intent(in) :: first_day   !uc0ɑꏊ̓tw肷
+    subroutine DclDrawAxisCalendar (side,first_day, title, unit, type,nd) !日・月・年に関する座標軸を描く．
+      character(len=*),  intent(in) :: side       !座標軸を書く場所を指定する
+      type(dcl_date),    intent(in) :: first_day   !ucで0に相当する場所の日付を指定する
       character(len=*), intent(in), optional :: title, unit
-      character(len=*),  intent(in), optional :: type        !NAA YMD Ŏw肷
-      integer, optional, intent(in) :: nd          !悷w肷
+      character(len=*),  intent(in), optional :: type        !年、月、日を YMD で指定する
+      integer, optional, intent(in) :: nd          !作画する日数を指定する
       character(len=8)              :: type0
 
       call sgoopn('DclDrawAxisCalendar', ' ')
@@ -320,12 +320,12 @@ module uspack
     end subroutine
       
 !----------------------------------
-!   UXYZPACK Wvf
-!---------------------------------- ^Cg`D
+!   UXYZPACK 座標軸要素
+!---------------------------------- タイトルを描く．
     subroutine DclDrawTitle(side,title,position,sw)
-      character(len=*), intent(in) :: side     !W`ꏊw肷
-      character(len=*), intent(in) :: title    !`^Cg
-      real,   optional, intent(in) :: position !ʒu:-1+1̊Ԃ̎l
+      character(len=*), intent(in) :: side     !座標軸を描く場所を指定する
+      character(len=*), intent(in) :: title    !描くタイトル
+      real,   optional, intent(in) :: position !位置:-1から+1の間の実数値
       integer,optional, intent(in) :: sw
 
       call sgoopn('DclDrawTitle', ' ')
@@ -341,10 +341,10 @@ module uspack
       call uspttl(side, isw, title, pos) 
       call sgocls('DclDrawTitle')
     end subroutine
-!---------------------------------- `D
+!---------------------------------- 軸を示す線分を描く．
     subroutine DclDrawAxisLine(side,sw)
-      character(len=*),  intent(in) :: side   !W`ꏊw肷
-      integer, optional, intent(in) :: sw     !`̑w肷
+      character(len=*),  intent(in) :: side   !座標軸を描く場所を指定する
+      integer, optional, intent(in) :: sw     !描く軸の属性を指定する
 
       call sgoopn('DclDrawAxisLine', ' ')
 
@@ -355,11 +355,11 @@ module uspack
       call uspaxs(side,isw)
       call sgocls('DclDrawAxisLine')
     end subroutine
-!---------------------------------- ڐ`D
+!---------------------------------- 目盛を描く．
     subroutine DclDrawTickmark(side, position, sw)
-      character(len=*), intent(in)        :: side      !ڐ`W̏ꏊ
-      integer,   intent(in), optional     :: sw        !`ڐ̑
-      real,      intent(in), dimension(:) :: position  !ڐ`ꏊ
+      character(len=*), intent(in)        :: side      !目盛を描く座標軸の場所
+      integer,   intent(in), optional     :: sw        !描く目盛の属性
+      real,      intent(in), dimension(:) :: position  !目盛を描く場所
       integer                             :: isw
 
       call sgoopn('DclDrawTickmark', ' ')
@@ -370,12 +370,12 @@ module uspack
       call uxptmk(side, isw, position, size(position)) 
       call sgocls('DclDrawTickmark')
     end subroutine
-!---------------------------------- Ŏw肵x`
+!---------------------------------- 文字列で指定したラベルを描く
     subroutine DclDrawAxisLabel(side, position, label, sw)
-      character(len=*), intent(in)               :: side     !x`W̏ꏊ
-      real,             intent(in), dimension(:) :: position !x`ꏊ
-      character(len=*), intent(in), dimension(:) :: label    !x
-      integer,          intent(in)               :: sw       !x̑
+      character(len=*), intent(in)               :: side     !ラベルを描く座標軸の場所
+      real,             intent(in), dimension(:) :: position !ラベルを描く場所
+      character(len=*), intent(in), dimension(:) :: label    !ラベル
+      integer,          intent(in)               :: sw       !ラベルの属性
       optional :: label, sw
 
       call sgoopn('DclDrawAxisLabel', ' ')
@@ -391,7 +391,7 @@ module uspack
       end if 
       call sgocls('DclDrawAxisLabel')
     end subroutine
-!---------------------------------- 炷B
+!---------------------------------- 軸をずらす。
     subroutine DclShiftAxis(side)
       character(len=*), intent(in) :: side
 
